Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(89)

Unified Diff: src/compiler/js-native-context-specialization.h

Issue 1410353002: [turbofan] Rename JSGlobalSpecialization to JSNativeContextSpecialization. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/compiler/js-native-context-specialization.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/js-native-context-specialization.h
diff --git a/src/compiler/js-global-specialization.h b/src/compiler/js-native-context-specialization.h
similarity index 74%
rename from src/compiler/js-global-specialization.h
rename to src/compiler/js-native-context-specialization.h
index eed9de89f6fd023bff28d9717625eba1f112c2dd..65c7733fea475b337790f62c151169ac2db29922 100644
--- a/src/compiler/js-global-specialization.h
+++ b/src/compiler/js-native-context-specialization.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef V8_COMPILER_JS_GLOBAL_SPECIALIZATION_H_
-#define V8_COMPILER_JS_GLOBAL_SPECIALIZATION_H_
+#ifndef V8_COMPILER_JS_NATIVE_CONTEXT_SPECIALIZATION_H_
+#define V8_COMPILER_JS_NATIVE_CONTEXT_SPECIALIZATION_H_
#include "src/base/flags.h"
#include "src/compiler/graph-reducer.h"
@@ -25,10 +25,11 @@ class JSOperatorBuilder;
class MachineOperatorBuilder;
// Specializes a given JSGraph to a given GlobalObject, potentially constant
// folding some {LoadGlobal} nodes or strength reducing some {StoreGlobal}
-// nodes.
-class JSGlobalSpecialization final : public AdvancedReducer {
+// nodes. And also specializes {LoadNamed} and {StoreNamed} nodes according
+// to type feedback (if available).
+class JSNativeContextSpecialization final : public AdvancedReducer {
public:
// Flags that control the mode of operation.
enum Flag {
@@ -37,9 +38,10 @@ class JSGlobalSpecialization final : public AdvancedReducer {
};
typedef base::Flags<Flag> Flags;
- JSGlobalSpecialization(Editor* editor, JSGraph* jsgraph, Flags flags,
- Handle<GlobalObject> global_object,
- CompilationDependencies* dependencies, Zone* zone);
+ JSNativeContextSpecialization(Editor* editor, JSGraph* jsgraph, Flags flags,
+ Handle<GlobalObject> global_object,
+ CompilationDependencies* dependencies,
+ Zone* zone);
Reduction Reduce(Node* node) final;
@@ -83,13 +85,13 @@ class JSGlobalSpecialization final : public AdvancedReducer {
CompilationDependencies* const dependencies_;
Zone* const zone_;
- DISALLOW_COPY_AND_ASSIGN(JSGlobalSpecialization);
+ DISALLOW_COPY_AND_ASSIGN(JSNativeContextSpecialization);
};
-DEFINE_OPERATORS_FOR_FLAGS(JSGlobalSpecialization::Flags)
+DEFINE_OPERATORS_FOR_FLAGS(JSNativeContextSpecialization::Flags)
} // namespace compiler
} // namespace internal
} // namespace v8
-#endif // V8_COMPILER_JS_GLOBAL_SPECIALIZATION_H_
+#endif // V8_COMPILER_JS_NATIVE_CONTEXT_SPECIALIZATION_H_
« no previous file with comments | « src/compiler/js-inlining.cc ('k') | src/compiler/js-native-context-specialization.cc » ('j') | no next file with comments »

Powered by Google App Engine
@@ -25,10 +25,11 @@ class JSOperatorBuilder;
class MachineOperatorBuilder;
-// Specializes a given JSGraph to a given GlobalObject, potentially constant
+// Specializes a given JSGraph to a given native context, potentially constant
// folding some {LoadGlobal} nodes or strength reducing some {StoreGlobal}
This is Rietveld 408576698